# Captions & Subtitles

Subtitle import/export, auto-captioning, and styled subtitle rendering.

## CaptionSegment

::: pymotion.captions.CaptionSegment

## WordTimestamp

::: pymotion.captions.WordTimestamp

## SubtitleClip

::: pymotion.captions.SubtitleClip

## AutoCaptions

::: pymotion.captions.AutoCaptions

## parse_srt

::: pymotion.captions.parse_srt

## parse_vtt

::: pymotion.captions.parse_vtt

## parse_ass

::: pymotion.captions.parse_ass

## import_subtitles

::: pymotion.captions.import_subtitles

## export_subtitles

::: pymotion.captions.export_subtitles

## get_caption_style

::: pymotion.captions.get_caption_style
